import jwt

from .secret import get_token_secret


# Need to change to accept request and attach user oauth id to request.oauth_id


def validateJWTAccessToken(token):
    secret_key_list = get_token_secret()

    audience = 'https://services-vehicle-ibpoflkccq-as.a.run.app/'

    for secret_key in secret_key_list:
        try:
            decoded_payload = jwt.decode(
                token, secret_key, audience=audience, algorithms=['HS256'])

            print(decoded_payload)

            return True

        except jwt.ExpiredSignatureError:
            print("Token has expired")
            return False

        except jwt.InvalidTokenError as e:
            print("Token is invalid, error: ", e)

        except Exception as e:
            print(f"An error occurred: {str(e)}")

    return False


def getJWTAccessTokenOauthId(token):

    try:
        # Decode the JWT without validation
        decoded_token = jwt.decode(token, options={"verify_signature": False})
        print('decoded_token', decoded_token)
        return decoded_token['user']
    except Exception as e:
        print("Error: ", e)



from setuptools import setup, find_packages

setup(
    name='driwecore',
    version='0.1.1',
    author='Jason Tai',
    description='This Pacakge is commont function that will be use by Drister or similiar team within the internal team',
    url = 'https://github.com/drister-my/driwecore',  
    download_url = 'https://github.com/drister-my/driwecore/archive/refs/tags/v_01.tar.gz',
    packages=find_packages(),
    install_requires=[
        # List your package dependencies here
        'pyjwt', 'google-cloud-secret-manager'
    ],
    classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
